<nav class="navbar navbar-default">
  <div class="container-fluid">
    <!-- Branding -->
    <div class="navbar-header">
      <button type="button" class="navbar-toggle collapsed" data-toggle="collapse" data-target="#smeagol-navbar-collapse" aria-expanded="false">
        <span class="sr-only">Toggle navigation</span>
        <span class="icon-bar"></span>
        <span class="icon-bar"></span>
        <span class="icon-bar"></span>
      </button>
      <a class="navbar-brand" href="#">{{ conf['name'] | title }}</a>
    </div>

    <!-- Collect the nav links, forms, and other content for toggling -->
    <div class="collapse navbar-collapse" id="smeagol-navbar-collapse">
      <!-- Left Side -->
      <ul class="nav navbar-nav">
        <li><a href="/">Home</a></li>
        <li><a href="/pages">Pages</a></li>
      </ul>
      <!-- Right Side -->
      <ul class="nav navbar-nav navbar-right">
        <li class="dropdown">
          <a href="#" class="dropdown-toggle" data-toggle="dropdown" role="button" aria-haspopup="true" aria-expanded="false">Actions <span class="caret"></span></a>
          <ul class="dropdown-menu">
            <li><a href="/page/create">Create New Page</a></li>
            <li role="separator" class="divider"></li>
            <li><a href="/page/edit/{{ conf['page_name'] }}">Edit Page</a></li>
            <li><a href="/page/delete/{{ conf['page_name'] }}">Delete Page</a></li>
            <li role="separator" class="divider"></li>
            <li><a href="#">Login</a></li>
          </ul>
        </li>
      </ul>
    </div><!-- /.navbar-collapse -->
  </div><!-- /.container-fluid -->
</nav>